==> haskell-glob-0.10.2-189.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-glob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Glob
version:              0.10.2
visibility:           public
id:                   Glob-0.10.2-AkNemguOk3X5pWzckA4YZJ
key:                  Glob-0.10.2-AkNemguOk3X5pWzckA4YZJ
license:              BSD-3-Clause
maintainer:           Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author:               Matti Niemenmaa
stability:            provisional
homepage:             http://iki.fi/matti.niemenmaa/glob/
synopsis:             Globbing library
description:
    A library for globbing: matching patterns against file paths.

category:             System
abi:                  32595f14777075cef6a3902c9358d52f
exposed:              True
exposed-modules:      System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules:
    System.FilePath.Glob.Base System.FilePath.Glob.Directory
    System.FilePath.Glob.Match System.FilePath.Glob.Simplify
    System.FilePath.Glob.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/Glob-0.10.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Glob-0.10.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Glob-0.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-glob
hs-libraries:         HSGlob-0.10.2-AkNemguOk3X5pWzckA4YZJ
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO filepath-1.4.300.1
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:   /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html:         /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-glob-0.10.2-190-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-glob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Glob
version:              0.10.2
visibility:           public
id:                   Glob-0.10.2-5kv8V0ytwO85Bs2S1wsFnS
key:                  Glob-0.10.2-5kv8V0ytwO85Bs2S1wsFnS
license:              BSD-3-Clause
maintainer:           Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author:               Matti Niemenmaa
stability:            provisional
homepage:             http://iki.fi/matti.niemenmaa/glob/
synopsis:             Globbing library
description:
    A library for globbing: matching patterns against file paths.

category:             System
abi:                  aa5962a1c994040871d4865312d4b641
exposed:              True
exposed-modules:      System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules:
    System.FilePath.Glob.Base System.FilePath.Glob.Directory
    System.FilePath.Glob.Match System.FilePath.Glob.Simplify
    System.FilePath.Glob.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/Glob-0.10.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Glob-0.10.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Glob-0.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-glob
hs-libraries:         HSGlob-0.10.2-5kv8V0ytwO85Bs2S1wsFnS
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO filepath-1.4.300.1
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:   /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html:         /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
